__version__ = "0.6.0"

# Copyright infos
__copyright_info_1__ = "3DFin: Forest Inventory Copyright (C) 2023-2025 Carlos Cabo & Diego Laino."
__copyright_info_2__ = (
    "This program comes with ABSOLUTELY NO WARRANTY. This is a free "
    "software, and you are welcome to redistribute it under certain conditions."
)

__copyright_info_3__ = "See LICENSE at the bottom of this tab for further details."

__license_msg__ = "See License at the bottom of 'About' tab for more details or visit <https://www.gnu.org/licenses/>"


# About the project
__about_1__ = (
    "This software has been developed at the Centre of Wildfire Research of "
    "Swansea University (UK) in collaboration with the Research Institute of\n"
    "Biodiversity (CSIC, Spain) and the Department of Mining Exploitation of the "
    "University of Oviedo (Spain). Funding provided by the UK NERC\nproject "
    "(NE/T001194/1):"
)

__nerc_project__ = "'Advancing 3D Fuel Mapping for Wildfire Behaviour and Risk Mitigation Modelling'"
__csic_project__ = (
    "'Advancing carbon emission estimations from wildfires applying "
    "artificial intelligence to 3D terrestrial point clouds'"
)
__about_2__ = "and by the Spanish Knowledge Generation project (PID2021-126790NB-I00):"
